@@ -39,6 +39,12 @@ eval 'exec /usr/bin/perl  -S $0 ${1+"$@"}'
 #Also make sure the script is executable for the users that shall use the servicemenu.
 #---------------------------------------------------------------------
 
+########### USER CONFIGURABLE VARIABLES #######################
+
+$CPDIALOGS="true" ; #Show dialogs when copying/moving, changing to "false" will suppress dialogs and *OVERWRITE WITHOUT WARNING* 
+
+
+
 ########### DIALOG MESSAGES, TRANSLATABLE STRINGS #############
 
 sub copy_dialog_msgs {
@@ -827,9 +833,10 @@ if ( $#ARGV lt 0 ) {
    die "This script is not meant to be run directly. It will run with the necessary arguments when called from the .desktop files when a root action is selected by right-clicking item(s) in konqueror/dolphin.\n" ;
 }
 
-# Check whether kdesudo is installed, and use it instead of kdesu to get root privileges.
+# Application checks
 &get_kde_path ;
 
+# Check whether kdesudo is installed, and use it instead of kdesu to get root privileges.
 if ( `which kdesudo` ) {
 	$SUCOMMAND = "$KDEBINPATH"."kdesudo -d --noignorebutton --"}
 elsif ( `which kdesu` ) {
@@ -890,7 +897,23 @@ sub open_with {
 	$APPNAME = shift @ARGV ;
 	$TARGET = join("' '", @ARGV) ;
 
-	if ( $APPNAME eq "kate" ) {
+	if ( $APPNAME eq "defaultfm" ) {
+	     chomp($APPNAME = `xdg-mime query default inode/directory | sed s/.desktop//`);
+	     if ( $APPNAME eq "kfmclient_dir" ) { $APPNAME = "konqueror"; }
+	     #use dolphin as fallback
+	     system "which $APPNAME" ;
+	        if ( $? ne 0 ) { $APPNAME = "dolphin"; }
+	}
+	elsif ( $APPNAME eq "defaultte" ) {
+	     chomp($APPNAME = `xdg-mime query default text/plain | sed s/.desktop//`);
+	     system "which $APPNAME" ;
+	     if ( $? ne 0 ) { 
+		if ( `which kate` ) { $APPNAME = "kate"; } #kate as fallback if available
+		else { $APPNAME = "kwrite"; } 
+             }   
+	}
+	#Redundant check in KDE4 ("defaultte" should handle choosing the text editor), kept for KDE3 compatibility 
+	elsif ( $APPNAME eq "kate" ) {
 	      system "which kate" ;
 	      if ( $? ne 0 ) {
 		  $APPNAME = "kwrite"; }
@@ -943,7 +966,13 @@ sub do_copy {
 	   #get the arguments)
 	   $OLDNAME = $ARGV[0] ;
 	   $NEWNAME = $ARGV[1] ;
-	   `cp -pr \'$OLDNAME\' \'$NEWNAME\'`;
+	#Check for kde-cp
+	if ( `which kde-cp` ) {
+	     if ( $CPDIALOGS ) { $COPYCOMMAND = "$KDEBINPATH"."kde-cp --"; }
+	     else { $COPYCOMMAND = "$KDEBINPATH"."kde-cp --overwrite --noninteractive --"; }
+	}
+        else { $COPYCOMMAND = "cp -r"; }
+	   `$COPYCOMMAND \'$OLDNAME\' \'$NEWNAME\'`;
 	}
 }
 #---End copy subroutines---
@@ -977,7 +1006,13 @@ sub do_rename {
 	   #get the arguments)
 	   $OLDNAME = $ARGV[0] ;
 	   $NEWNAME = $ARGV[1] ;
-	   `mv \'$OLDNAME\' \'$NEWNAME\'`;
+	#Check for kde-mv
+	if ( `which kde-mv` ) {
+	     if ( $CPDIALOGS ) { $MOVECOMMAND = "$KDEBINPATH"."kde-mv --"; }
+	     else { $MOVECOMMAND = "$KDEBINPATH"."kde-mv --overwrite --noninteractive --"; }
+	}
+        else { $MOVECOMMAND = "mv"}
+	   `$MOVECOMMAND \'$OLDNAME\' \'$NEWNAME\'`;
 	}
 }
 #---End rename subroutines---
